@@ -5,19 +5,19 @@ from jackal.views.base import JackalAPIView
 
 
 class ListCreateGeneric(JackalAPIView):
-    def get_response_data(self, request, **kwargs):
+    def get_response_data(self):
         serializer_class = self.get_serializer_class()
-        filtered_queryset = self.get_filtered_queryset(request, **kwargs)
+        filtered_queryset = self.get_filtered_queryset()
         ser = serializer_class(instance=filtered_queryset, many=True, context=self.get_serializer_context())
         return ser.data
 
     def list(self, request, **kwargs):
-        response_data = self.get_response_data(request, **kwargs)
+        response_data = self.get_response_data()
         return self.simple_response(response_data)
 
     def create(self, request, **kwargs):
         model = self.get_model()
-        obj = model(**self.get_inspected_data(request))
+        obj = model(**self.get_inspected_data())
         if self.bind_user_field:
             setattr(obj, self.bind_user_field, self.binding_user())
         obj.save()
@@ -25,41 +25,44 @@ class ListCreateGeneric(JackalAPIView):
 
 
 class DetailUpdateDestroyGeneric(JackalAPIView):
-    def get_response_data(self, request, **kwargs):
-        obj = self.get_object(request, **kwargs)
+    def get_response_data(self):
+        obj = self.get_object()
         ser = self.serializer_class(obj, context=self.get_serializer_context())
         return ser.data
 
     def detail(self, request, **kwargs):
-        response_data = self.get_response_data(request, **kwargs)
+        response_data = self.get_response_data()
         return self.simple_response(response_data)
 
     def update(self, request, **kwargs):
-        obj = self.get_object(request, **kwargs)
-        model_update(obj, **self.get_inspected_data(request))
+        obj = self.get_object()
+        model_update(obj, **self.get_inspected_data())
         return self.simple_response({'id': obj.id})
 
     def destroy(self, request, **kwargs):
-        obj = self.get_object(request, **kwargs)
+        obj = self.get_object()
         obj.delete()
         return self.simple_response()
 
 
 class PaginateListGeneric(JackalAPIView):
+    result_root = 'data'
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.paginator = None
 
-    def get_paginator(self, request, queryset):
-        page_num = request.query_params.get(self.page_number_key, self.default_page_number)
-        page_length = request.query_params.get(self.page_length_key, self.default_page_length)
+    def get_paginator(self, queryset):
+        query_params = self.request.query_params
+        page_num = query_params.get(self.page_number_key, self.default_page_number)
+        page_length = query_params.get(self.page_length_key, self.default_page_length)
 
         paginator_class = self.get_paginator_class()
         return paginator_class(queryset, page_num, page_length)
 
-    def get_response_data(self, request, **kwargs):
-        queryset = self.get_filtered_queryset(request, **kwargs)
-        self.paginator = self.get_paginator(request, queryset)
+    def get_response_data(self):
+        queryset = self.get_filtered_queryset()
+        self.paginator = self.get_paginator(queryset)
         paginated_data = self.paginator.serialized_data(
             serializer_class=self.get_serializer_class(),
             context=self.get_serializer_context()
@@ -67,14 +70,15 @@ class PaginateListGeneric(JackalAPIView):
         return paginated_data
 
     def paginated_list(self, request, **kwargs):
-        result = self.get_response_data(request, **kwargs)
+        result = self.get_response_data()
         meta_data = self.paginator.meta_data()
         return self.simple_response(result, meta=meta_data)
 
 
 class SimpleGeneric(JackalAPIView):
     def wrapper(self, request, method='get', **kwargs):
-        return getattr(self, '{}_func'.format(method))(request, **kwargs)
+        handler = getattr(self, '{}_func'.format(method))
+        return handler(request, **kwargs)
 
     def get_func(self, request, **kwargs):
         pass
@@ -186,27 +190,27 @@ class PaginateListMixin(PaginateListGeneric):
 
 class PostMixin(SimpleGeneric):
     def post(self, request, **kwargs):
-        return self.wrapper(request, method='post', **kwargs)
+        return self.wrapper(request, method=request.method.lower(), **kwargs)
 
 
 class GetMixin(SimpleGeneric):
     def get(self, request, **kwargs):
-        return self.wrapper(request, method='get', **kwargs)
+        return self.wrapper(request, method=request.method.lower(), **kwargs)
 
 
 class PutMixin(SimpleGeneric):
     def put(self, request, **kwargs):
-        return self.wrapper(request, method='put', **kwargs)
+        return self.wrapper(request, method=request.method.lower(), **kwargs)
 
 
 class PatchMixin(SimpleGeneric):
     def patch(self, request, **kwargs):
-        return self.wrapper(request, method='patch', **kwargs)
+        return self.wrapper(request, method=request.method.lower(), **kwargs)
 
 
 class DeleteMixin(SimpleGeneric):
     def delete(self, request, **kwargs):
-        return self.wrapper(request, method='delete', **kwargs)
+        return self.wrapper(request, method=request.method.lower(), **kwargs)
 
 
 class LabelValueListMixin(LabelValueListGeneric):
